=======
Credits
=======

Lead developer
----------------

* Veronika Kotova <veronika.kotova@tum.de>

Contributors
------------

* Ziga Avsec <avsec@in.tum.de>

Acknowledgement
---------------

* Jun Cheng
* Basak Eraslan
* Vicente Yepez
* Gagneur Lab <https://gagneurlab.in.tum.de>
